@@ -36,11 +36,13 @@
 #include <EntityDisplayAttribute>
 #include <ETMViewStateSaver>
 
-#include <KCalCore/Todo>
-#include <KCalCore/CalFilter>
+#include <KCalendarCore/Todo>
+#include <KCalendarCore/CalFilter>
 
 #include <KCalUtils/RecurrenceActions>
 
+#include <KHolidays/HolidayRegion>
+
 #include <KCheckableProxyModel>
 #include <KGuiItem>
 #include <KLocalizedString>
@@ -53,7 +55,7 @@
 #include <QKeyEvent>
 #include <QSortFilterProxyModel>
 
-using namespace KCalCore;
+using namespace KCalendarCore;
 using namespace EventViews;
 using namespace Akonadi;
 
@@ -107,10 +109,19 @@ void EventView::defaultAction(const Akonadi::Item &aitem)
     }
 }
 
-void EventView::setHolidayRegion(const KHolidays::HolidayRegionPtr &holidayRegion)
+void EventView::setHolidayRegions(const QStringList &regions)
 {
     Q_D(EventView);
-    d->mHolidayRegion = holidayRegion;
+    qDeleteAll(d->mHolidayRegions);
+    d->mHolidayRegions.clear();
+    for (const QString &regionStr : regions) {
+        KHolidays::HolidayRegion *region = new KHolidays::HolidayRegion(regionStr);
+        if (region->isValid()) {
+            d->mHolidayRegions.append(region);
+        } else {
+            delete region;
+        }
+    }
 }
 
 int EventView::showMoveRecurDialog(const Incidence::Ptr &inc, const QDate &date)
@@ -144,6 +155,7 @@ int EventView::showMoveRecurDialog(const Incidence::Ptr &inc, const QDate &date)
             return KCalUtils::RecurrenceActions::questionSelectedFutureAllCancel(
                 message, caption, itemSelected, itemFuture, itemAll, this);
         }
+        Q_FALLTHROUGH();
 
     default:
         Q_ASSERT(availableOccurrences & KCalUtils::RecurrenceActions::SelectedOccurrence);
@@ -279,8 +291,7 @@ bool EventView::hasConfigurationDialog() const
     return false;
 }
 
-void EventView::setDateRange(const QDateTime &start, const QDateTime &end,
-                             const QDate &preferredMonth)
+void EventView::setDateRange(const QDateTime &start, const QDateTime &end, const QDate &preferredMonth)
 {
     Q_D(EventView);
 
@@ -471,7 +482,6 @@ QPair<QDateTime, QDateTime> EventView::actualDateRange(const QDateTime &start, c
 /*
 void EventView::incidencesAdded( const Akonadi::Item::List & )
 {
-
 }
 
 void EventView::incidencesAboutToBeRemoved( const Akonadi::Item::List & )
@@ -513,7 +523,7 @@ void EventView::setChanges(Changes changes)
 {
     Q_D(EventView);
     if (d->mChanges == NothingChanged) {
-        QMetaObject::invokeMethod(this, "updateView", Qt::QueuedConnection);
+        QMetaObject::invokeMethod(this, &EventView::updateView, Qt::QueuedConnection);
     }
 
     d->mChanges = changes;
@@ -598,33 +608,33 @@ Akonadi::Collection::Id EventView::collectionId() const
     return d->mCollectionId;
 }
 
-bool EventView::makesWholeDayBusy(const KCalCore::Incidence::Ptr &incidence) const
+bool EventView::makesWholeDayBusy(const KCalendarCore::Incidence::Ptr &incidence) const
 {
     // Must be event
     // Must be all day
     // Must be marked busy (TRANSP: OPAQUE)
     // You must be attendee or organizer
 
-    if (incidence->type() != KCalCore::Incidence::TypeEvent || !incidence->allDay()) {
+    if (incidence->type() != KCalendarCore::Incidence::TypeEvent || !incidence->allDay()) {
         return false;
     }
 
-    KCalCore::Event::Ptr ev = incidence.staticCast<KCalCore::Event>();
+    KCalendarCore::Event::Ptr ev = incidence.staticCast<KCalendarCore::Event>();
 
-    if (ev->transparency() != KCalCore::Event::Opaque) {
+    if (ev->transparency() != KCalendarCore::Event::Opaque) {
         return false;
     }
 
     // Last check: must be organizer or attendee:
 
-    if (kcalPreferences()->thatIsMe(ev->organizer()->email())) {
+    if (kcalPreferences()->thatIsMe(ev->organizer().email())) {
         return true;
     }
 
-    KCalCore::Attendee::List attendees = ev->attendees();
-    KCalCore::Attendee::List::ConstIterator it;
+    KCalendarCore::Attendee::List attendees = ev->attendees();
+    KCalendarCore::Attendee::List::ConstIterator it;
     for (it = attendees.constBegin(); it != attendees.constEnd(); ++it) {
-        if (kcalPreferences()->thatIsMe((*it)->email())) {
+        if (kcalPreferences()->thatIsMe((*it).email())) {
             return true;
         }
     }
@@ -660,8 +670,7 @@ QString EventView::iconForItem(const Akonadi::Item &item)
     return iconName;
 }
 
-void EventView::onCollectionChanged(const Akonadi::Collection &collection,
-                                    const QSet<QByteArray> &changedAttributes)
+void EventView::onCollectionChanged(const Akonadi::Collection &collection, const QSet<QByteArray> &changedAttributes)
 {
     Q_UNUSED(collection);
     if (changedAttributes.contains("AccessRights")) {
