@@ -30,7 +30,7 @@
 
 #include <CalendarSupport/Utils>
 
-#include <KCalCore/Journal>
+#include <KCalendarCore/Journal>
 
 #include <KCalUtils/IncidenceFormatter>
 #include <Akonadi/Calendar/ETMCalendar>
@@ -52,7 +52,7 @@ JournalDateView::JournalDateView(const Akonadi::ETMCalendar::Ptr &calendar, QWid
     , mChanger(nullptr)
 {
     auto layout = new QVBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
 }
 
@@ -103,8 +103,8 @@ void JournalDateView::addJournal(const Akonadi::Item &j)
             this, &JournalDateView::editIncidence);
     connect(entry, &JournalFrame::incidenceSelected,
             this, &JournalDateView::incidenceSelected);
-    connect(entry, SIGNAL(printJournal(KCalCore::Journal::Ptr,bool)),
-            SIGNAL(printJournal(KCalCore::Journal::Ptr,bool)));
+    connect(entry, QOverload<const KCalendarCore::Journal::Ptr &, bool>::of(&JournalFrame::printJournal),
+            this, QOverload<const KCalendarCore::Journal::Ptr &, bool>::of(&JournalDateView::printJournal));
 }
 
 Akonadi::Item::List JournalDateView::journals() const
@@ -300,7 +300,7 @@ void JournalFrame::readJournal(const Akonadi::Item &j)
 {
     int baseFontSize = QFontDatabase::systemFont(QFontDatabase::GeneralFont).pointSize();
     mJournal = j;
-    const KCalCore::Journal::Ptr journal = CalendarSupport::journal(j);
+    const KCalendarCore::Journal::Ptr journal = CalendarSupport::journal(j);
     mBrowser->clear();
     QTextCursor cursor = QTextCursor(mBrowser->textCursor());
     cursor.movePosition(QTextCursor::Start);
