@@ -31,42 +31,36 @@
 #include "incidencetreemodel.h"
 #include "tododelegates.h"
 #include "todomodel.h"
-#include "todoviewsortfilterproxymodel.h"
 #include "todoviewquickaddline.h"
 #include "todoviewquicksearch.h"
+#include "todoviewsortfilterproxymodel.h"
 #include "todoviewview.h"
-#include "helper.h"
+#include "calendarview_debug.h"
+
+#include <AkonadiCore/EntityMimeTypeFilterModel>
+#include <AkonadiCore/TagFetchJob>
+
+#include <AkonadiWidgets/ETMViewStateSaver>
 
-#include <CalendarSupport/CategoryConfig>
-#include <CalendarSupport/CollectionSelection>
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 
 #include <Libkdepim/KDatePickerPopup>
 
-#include <entitymimetypefiltermodel.h>
-#include <ETMViewStateSaver>
-#include <TagFetchJob>
-#include <Tag>
+#include <KCalendarCore/CalFormat>
 
-#include <KCalCore/CalFormat>
-#include <QIcon>
-#include <KIconLoader>
 #include <KJob>
-#include "calendarview_debug.h"
 
-#include <QCheckBox>
 #include <QGridLayout>
 #include <QHeaderView>
+#include <QIcon>
 #include <QMenu>
 #include <QToolButton>
-#include <QItemSelection>
-#include <QTimer>
 
 Q_DECLARE_METATYPE(QPointer<QMenu>)
 
 using namespace EventViews;
-using namespace KCalCore;
+using namespace KCalendarCore;
 
 namespace EventViews {
 // We share this struct between all views, for performance and memory purposes
@@ -104,7 +98,7 @@ public:
     {
         const QString todoMimeType = QStringLiteral("application/x-vnd.akonadi.calendar.todo");
         if (flat) {
-            foreach (TodoView *view, views) {
+            for (TodoView *view : qAsConst(views)) {
                 // In flatview dropping confuses users and it's very easy to drop into a child item
                 view->mView->setDragDropMode(QAbstractItemView::DragOnly);
                 view->setFlatView(flat, /**propagate=*/ false);   // So other views update their toggle icon
@@ -125,7 +119,7 @@ public:
         } else {
             delete todoTreeModel;
             todoTreeModel = new IncidenceTreeModel(QStringList() << todoMimeType, parent);
-            foreach (TodoView *view, views) {
+            for (TodoView *view : qAsConst(views)) {
                 QObject::connect(todoTreeModel, &IncidenceTreeModel::indexChangedParent, view,
                                  &TodoView::expandIndex);
                 QObject::connect(todoTreeModel, &IncidenceTreeModel::batchInsertionFinished, view,
@@ -139,7 +133,7 @@ public:
             todoFlatModel = nullptr;
         }
 
-        foreach (TodoView *view, views) {
+        for (TodoView *view : qAsConst(views)) {
             view->mFlatViewButton->blockSignals(true);
             // We block signals to avoid recursion, we have two TodoViews and mFlatViewButton is synchronized
             view->mFlatViewButton->setChecked(flat);
@@ -211,8 +205,8 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     if (!mSidebarView) {
         mQuickSearch = new TodoViewQuickSearch(calendar(), this);
         mQuickSearch->setVisible(prefs->enableTodoQuickSearch());
-        connect(mQuickSearch, SIGNAL(searchTextChanged(QString)),
-                mProxyModel, SLOT(setFilterRegExp(QString)));
+        connect(mQuickSearch, &TodoViewQuickSearch::searchTextChanged,
+                mProxyModel, QOverload<const QString&>::of(&QSortFilterProxyModel::setFilterRegExp));
         connect(mQuickSearch, &TodoViewQuickSearch::searchTextChanged, this,
                 &TodoView::restoreViewState);
         connect(mQuickSearch, &TodoViewQuickSearch::filterCategoryChanged, mProxyModel,
@@ -236,12 +230,12 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     mView->setDragDropMode(QAbstractItemView::DragDrop);
 
     mView->setExpandsOnDoubleClick(false);
-    mView->setEditTriggers(QAbstractItemView::SelectedClicked
-                           |QAbstractItemView::EditKeyPressed);
+    mView->setEditTriggers(QAbstractItemView::SelectedClicked | QAbstractItemView::EditKeyPressed);
 
-    connect(mView->header(), &QHeaderView::geometriesChanged, this,
-            &TodoView::scheduleResizeColumns);
-    connect(mView, &TodoViewView::visibleColumnCountChanged, this, &TodoView::resizeColumns);
+    connect(mView->header(), &QHeaderView::geometriesChanged,
+            this, &TodoView::scheduleResizeColumns);
+    connect(mView, &TodoViewView::visibleColumnCountChanged,
+            this, &TodoView::resizeColumns);
 
     TodoRichTextDelegate *richTextDelegate = new TodoRichTextDelegate(mView);
     mView->setItemDelegateForColumn(TodoModel::SummaryColumn, richTextDelegate);
@@ -306,7 +300,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     }
 
     QGridLayout *layout = new QGridLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     if (!mSidebarView) {
         layout->addWidget(mQuickSearch, 0, 0, 1, 2);
     }
@@ -334,7 +328,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
 
     mItemPopupMenuItemOnlyEntries << mItemPopupMenu->addAction(
         i18nc("@action:inmenu show the to-do", "&Show"),
-        this, SLOT(showTodo()));
+        this, &TodoView::showTodo);
 
     QAction *a = mItemPopupMenu->addAction(
         i18nc("@action:inmenu edit the to-do", "&Edit..."),
@@ -351,38 +345,35 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     mItemPopupMenuItemOnlyEntries << mItemPopupMenu->addAction(
         QIcon::fromTheme(QStringLiteral("document-print-preview")),
         i18nc("@action:inmenu print preview the to-do", "Print Previe&w..."),
-        this, SIGNAL(printPreviewTodo()));
+        this, &TodoView::printPreviewTodo);
     mItemPopupMenu->addSeparator();
-    a = mItemPopupMenu->addAction(
-        KIconLoader::global()->loadIcon(QStringLiteral("edit-delete"), KIconLoader::NoGroup,
-                                        KIconLoader::SizeSmall),
+    a = mItemPopupMenu->addAction(QIcon::fromTheme(QStringLiteral("edit-delete")),
         i18nc("@action:inmenu delete the to-do", "&Delete"),
-        this, SLOT(deleteTodo()));
+        this, &TodoView::deleteTodo);
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
     mItemPopupMenu->addSeparator();
 
     mItemPopupMenu->addAction(
-        KIconLoader::global()->loadIcon(
-            QStringLiteral("view-calendar-tasks"), KIconLoader::NoGroup, KIconLoader::SizeSmall),
+        QIcon::fromTheme(QStringLiteral("view-calendar-tasks")),
         i18nc("@action:inmenu create a new to-do", "New &To-do..."),
-        this, SLOT(newTodo()));
+        this, &TodoView::newTodo);
 
     a = mItemPopupMenu->addAction(
         i18nc("@action:inmenu create a new sub-to-do", "New Su&b-to-do..."),
-        this, SLOT(newSubTodo()));
+        this, &TodoView::newSubTodo);
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
     mMakeTodoIndependent = mItemPopupMenu->addAction(
         i18nc("@action:inmenu", "&Make this To-do Independent"),
-        this, SIGNAL(unSubTodoSignal()));
+        this, &TodoView::unSubTodoSignal);
 
     mMakeSubtodosIndependent
         = mItemPopupMenu->addAction(
-        i18nc("@action:inmenu", "Make all Sub-to-dos &Independent"),
-        this, SIGNAL(unAllSubTodoSignal()));
+              i18nc("@action:inmenu", "Make all Sub-to-dos &Independent"),
+              this, &TodoView::unAllSubTodoSignal);
 
     mItemPopupMenuItemOnlyEntries << mMakeTodoIndependent;
     mItemPopupMenuItemOnlyEntries << mMakeSubtodosIndependent;
@@ -392,44 +383,36 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
 
     mItemPopupMenu->addSeparator();
 
-    a
-        = mItemPopupMenu->addAction(KIconLoader::global()->loadIcon(QStringLiteral("appointment-new"),
-                                                                    KIconLoader::NoGroup,
-                                                                    KIconLoader::SizeSmall),
-                                    i18n("Create Event"),
-                                    this, SLOT(createEvent()));
+    a = mItemPopupMenu->addAction(QIcon::fromTheme(QStringLiteral("appointment-new")),
+                                  i18nc("@action:inmenu", "Create Event"),
+                                  this, SLOT(createEvent()));
     a->setObjectName(QStringLiteral("createevent"));
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
-    a
-        = mItemPopupMenu->addAction(KIconLoader::global()->loadIcon(QStringLiteral("view-pim-notes"),
-                                                                    KIconLoader::NoGroup,
-                                                                    KIconLoader::SizeSmall),
-                                    i18n("Create Note"),
-                                    this, SLOT(createNote()));
+    a = mItemPopupMenu->addAction(QIcon::fromTheme(QStringLiteral("view-pim-notes")),
+                                  i18nc("@action:inmenu", "Create Note"),
+                                  this, SLOT(createNote()));
     a->setObjectName(QStringLiteral("createnote"));
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
     mItemPopupMenu->addSeparator();
 
-    mCopyPopupMenu
-        = new KPIM::KDatePickerPopup(KPIM::KDatePickerPopup::NoDate
-                                     |KPIM::KDatePickerPopup::DatePicker
-                                     |KPIM::KDatePickerPopup::Words,
-                                     QDate::currentDate(), this);
+    mCopyPopupMenu = new KPIM::KDatePickerPopup(KPIM::KDatePickerPopup::NoDate
+                                                |KPIM::KDatePickerPopup::DatePicker
+                                                |KPIM::KDatePickerPopup::Words,
+                                                QDate::currentDate(), this);
     mCopyPopupMenu->setTitle(i18nc("@title:menu", "&Copy To"));
 
     connect(mCopyPopupMenu, &KPIM::KDatePickerPopup::dateChanged, this, &TodoView::copyTodoToDate);
 
     connect(mCopyPopupMenu, &KPIM::KDatePickerPopup::dateChanged, mItemPopupMenu, &QMenu::hide);
 
-    mMovePopupMenu
-        = new KPIM:: KDatePickerPopup(KPIM::KDatePickerPopup::NoDate
-                                      |KPIM::KDatePickerPopup::DatePicker
-                                      |KPIM::KDatePickerPopup::Words,
-                                      QDate::currentDate(), this);
+    mMovePopupMenu = new KPIM:: KDatePickerPopup(KPIM::KDatePickerPopup::NoDate
+                                                 |KPIM::KDatePickerPopup::DatePicker
+                                                 |KPIM::KDatePickerPopup::Words,
+                                                 QDate::currentDate(), this);
     mMovePopupMenu->setTitle(i18nc("@title:menu", "&Move To"));
 
     connect(mMovePopupMenu, &KPIM::KDatePickerPopup::dateChanged, this, &TodoView::setNewDate);
@@ -442,7 +425,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     mItemPopupMenu->addSeparator();
     mItemPopupMenu->addAction(
         i18nc("@action:inmenu delete completed to-dos", "Pur&ge Completed"),
-        this, SIGNAL(purgeCompletedSignal()));
+        this, &TodoView::purgeCompletedSignal);
 
     mPriorityPopupMenu = new QMenu(this);
     mPriority[ mPriorityPopupMenu->addAction(
@@ -672,21 +655,18 @@ void TodoView::clearSelection()
     mView->selectionModel()->clearSelection();
 }
 
-void TodoView::addTodo(const QString &summary, const Akonadi::Item &parentItem,
-                       const QStringList &categories)
+void TodoView::addTodo(const QString &summary, const Akonadi::Item &parentItem, const QStringList &categories)
 {
     const QString summaryTrimmed = summary.trimmed();
     if (!changer() || summaryTrimmed.isEmpty()) {
         return;
     }
 
-    KCalCore::Todo::Ptr parent = CalendarSupport::todo(parentItem);
+    KCalendarCore::Todo::Ptr parent = CalendarSupport::todo(parentItem);
 
-    KCalCore::Todo::Ptr todo(new KCalCore::Todo);
+    KCalendarCore::Todo::Ptr todo(new KCalendarCore::Todo);
     todo->setSummary(summaryTrimmed);
-    todo->setOrganizer(
-        Person::Ptr(new Person(CalendarSupport::KCalPrefs::instance()->fullName(),
-                               CalendarSupport::KCalPrefs::instance()->email())));
+    todo->setOrganizer(Person(CalendarSupport::KCalPrefs::instance()->fullName(), CalendarSupport::KCalPrefs::instance()->email()));
 
     todo->setCategories(categories);
 
@@ -752,8 +732,7 @@ void TodoView::contextMenu(const QPoint &pos)
                 const bool incidenceIsRO = !calendar()->hasRight(item,
                                                                  Akonadi::Collection::CanChangeItem);
 
-                enable = hasItem && (!actionIsRw
-                                     || !incidenceIsRO);
+                enable = hasItem && (!actionIsRw || !incidenceIsRO);
             }
         } else {
             enable = false;
@@ -768,9 +747,8 @@ void TodoView::contextMenu(const QPoint &pos)
         if (incidencePtr) {
             const bool hasRecId = incidencePtr->hasRecurrenceId();
             if (calendar()) {
-                mMakeSubtodosIndependent->setEnabled(!hasRecId
-                                                     && !calendar()->childItems(
-                                                         incidencePtr->uid()).isEmpty());
+                mMakeSubtodosIndependent->setEnabled(
+                    !hasRecId && !calendar()->childItems(incidencePtr->uid()).isEmpty());
             }
             mMakeTodoIndependent->setEnabled(!hasRecId && !incidencePtr->relatedTo().isEmpty());
         }
@@ -889,14 +867,14 @@ void TodoView::copyTodoToDate(const QDate &date)
         = sModels->todoModel->data(origIndex,
                                    Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
 
-    const KCalCore::Todo::Ptr orig = CalendarSupport::todo(origItem);
+    const KCalendarCore::Todo::Ptr orig = CalendarSupport::todo(origItem);
     if (!orig) {
         return;
     }
 
-    KCalCore::Todo::Ptr todo(orig->clone());
+    KCalendarCore::Todo::Ptr todo(orig->clone());
 
-    todo->setUid(KCalCore::CalFormat::createUniqueId());
+    todo->setUid(KCalendarCore::CalFormat::createUniqueId());
 
     QDateTime due = todo->dtDue();
     due.setDate(date);
@@ -933,7 +911,7 @@ QMenu *TodoView::createCategoryPopupMenu()
     }
 
     const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
+    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
     Q_ASSERT(todo);
 
     const QStringList checkedCategories = todo->categories();
@@ -958,7 +936,8 @@ void TodoView::onTagsFetched(KJob *job)
     const QStringList checkedCategories = job->property("checkedCategories").toStringList();
     QPointer<QMenu> menu = job->property("menu").value<QPointer<QMenu> >();
     if (menu) {
-        Q_FOREACH (const Akonadi::Tag &tag, fetchJob->tags()) {
+        const auto lst = fetchJob->tags();
+        for (const Akonadi::Tag &tag : lst) {
             const QString name = tag.name();
             QAction *action = menu->addAction(name);
             action->setCheckable(true);
@@ -978,11 +957,11 @@ void TodoView::setNewDate(const QDate &date)
     }
 
     const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
+    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
     Q_ASSERT(todo);
 
     if (calendar()->hasRight(todoItem, Akonadi::Collection::CanChangeItem)) {
-        KCalCore::Todo::Ptr oldTodo(todo->clone());
+        KCalendarCore::Todo::Ptr oldTodo(todo->clone());
 
         QDateTime dt(date);
 
@@ -1006,11 +985,11 @@ void TodoView::setNewPercentage(QAction *action)
     }
 
     const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
+    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
     Q_ASSERT(todo);
 
     if (calendar()->hasRight(todoItem, Akonadi::Collection::CanChangeItem)) {
-        KCalCore::Todo::Ptr oldTodo(todo->clone());
+        KCalendarCore::Todo::Ptr oldTodo(todo->clone());
 
         int percentage = mPercentage.value(action);
         if (percentage == 100) {
@@ -1036,9 +1015,9 @@ void TodoView::setNewPriority(QAction *action)
         return;
     }
     const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
+    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
     if (calendar()->hasRight(todoItem, Akonadi::Collection::CanChangeItem)) {
-        KCalCore::Todo::Ptr oldTodo(todo->clone());
+        KCalendarCore::Todo::Ptr oldTodo(todo->clone());
         todo->setPriority(mPriority[action]);
 
         changer()->modifyIncidence(todoItem, oldTodo, this);
@@ -1053,10 +1032,10 @@ void TodoView::changedCategories(QAction *action)
     }
 
     const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
+    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
     Q_ASSERT(todo);
     if (calendar()->hasRight(todoItem, Akonadi::Collection::CanChangeItem)) {
-        KCalCore::Todo::Ptr oldTodo(todo->clone());
+        KCalendarCore::Todo::Ptr oldTodo(todo->clone());
 
         const QString cat = action->data().toString();
         QStringList categories = todo->categories();
@@ -1143,11 +1122,9 @@ void TodoView::onRowsInserted(const QModelIndex &parent, int start, int end)
             // don't destroy complex selections, not applicable now (only single
             // selection allowed), but for the future...
             int colCount = static_cast<int>(TodoModel::ColumnCount);
-            mView->selectionModel()->select(QItemSelection(idx,
-                                                           mView->model()->index(start,
-                                                                                 colCount - 1)),
-                                            QItemSelectionModel::ClearAndSelect
-                                            |QItemSelectionModel::Rows);
+            mView->selectionModel()->select(
+                QItemSelection(idx, mView->model()->index(start, colCount - 1)),
+                QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
         }
         return;
     }
@@ -1165,8 +1142,7 @@ void TodoView::onRowsInserted(const QModelIndex &parent, int start, int end)
     }
 }
 
-void TodoView::getHighlightMode(bool &highlightEvents, bool &highlightTodos,
-                                bool &highlightJournals)
+void TodoView::getHighlightMode(bool &highlightEvents, bool &highlightTodos, bool &highlightJournals)
 {
     highlightTodos = preferences()->highlightTodos();
     highlightEvents = !highlightTodos;
@@ -1197,8 +1173,10 @@ void TodoView::resizeColumns()
     // Calculate size of non-stretchable columns:
     int size = 0;
     for (int i = 0; i < TodoModel::ColumnCount; ++i) {
-        if (!mView->isColumnHidden(i) && i != TodoModel::SummaryColumn
-            && i != TodoModel::DescriptionColumn && i != TodoModel::CategoriesColumn) {
+        if (!mView->isColumnHidden(i)
+            && i != TodoModel::SummaryColumn
+            && i != TodoModel::DescriptionColumn
+            && i != TodoModel::CategoriesColumn) {
             size += mView->columnWidth(i);
         }
     }
@@ -1216,7 +1194,7 @@ void TodoView::resizeColumns()
     }
 
     if (remainingSize < requiredSize) {
-        // We have too little size (that's what she...), so lets use an horizontal scrollbar and make these columns use whatever they need.
+        // Too little size, so let's use a horizontal scrollbar
         mView->resizeColumnToContents(TodoModel::SummaryColumn);
         mView->resizeColumnToContents(TodoModel::DescriptionColumn);
     } else if (descriptionVisible) {
